import { IDocElement, IHrefLinkElement, ICodeLinkElement } from './IDocElement';
import Token from './Token';
import Tokenizer from './Tokenizer';
export default class DocElementParser {
    /**
     * Matches only strings that contain characters for words.
     * Any non word characters or spaces, will be present in the third entry in the match results
     * if they exist.
     */
    private static _wordRegEx;
    /**
     * Matches a href reference. This is used to get an idea whether a given reference is for an href
     * or an API definition reference.
     *
     * For example, the following would be matched:
     * 'http://'
     * 'https://'
     *
     * The following would not be matched:
     * '@microsoft/sp-core-library:Guid.newGuid'
     * 'Guid.newGuid'
     * 'Guid'
     */
    private static _hrefRegEx;
    static makeTextElement(text: string): IDocElement;
    static parse(tokenizer: Tokenizer, reportError: (message: string) => void): IDocElement[];
    /**
     * This method parses the semantic information in an \@link JSDoc tag, creates and returns a
     * linkDocElement with the corresponding information. If the corresponding inline tag \@link is
     * not formatted correctly an error will be reported.
     *
     * The format for the \@link tag is {\@link url or API defintion reference | display text}, where
     * the '|' is only needed if the optional display text is given.
     *
     * Examples:
     * \{@link http://microsoft.com | microsoft home \}
     * \{@link http://microsoft.com \}
     * \{@link @microsoft/sp-core-library:Guid.newGuid | new Guid Object \}
     * \{@link @microsoft/sp-core-library:Guid.newGuid \}
     */
    static parseLinkTag(tokenItem: Token, reportError: (message: string) => void): IHrefLinkElement | ICodeLinkElement;
}
