import { IDocItem, IDocPackage } from './IDocItem';
import { IApiDefinitionReference } from './IApiDefinitionReference';
/**
 * Used to describe a parsed package name in the form of
 * scopedName/packageName. Ex: @microsoft/sp-core-library.
 */
export interface IParsedScopeName {
    /**
     * The scope prefix. Ex: @microsoft.
     */
    scope: string;
    /**
     * The specific package name. Ex: sp-core-library.
     */
    name: string;
}
/**
 * A loader for locating the IDocItem associated with a given project and API item.
 * The DocItem loader utilizes the json files generated by the API-Extractor ApiJsonGenerator.
 * The IDocItem can then be used to enforce correct API usage, like enforcing internal.
 * To use to DocItemLoader: provide a projectFolder to construct a instance of the DocItemLoader,
 * then use DocItemLoader.getItem to retrieve the IDocItem of a particular API item.
 */
export default class DocItemLoader {
    private cache;
    private projectFolder;
    /**
     * The projectFolder is the top-level folder containing package.json for a project
     * that we are compiling.
     */
    constructor(projectFolder: string);
    /**
     * Attempts to retrieve an API item from the provided apiDefinitionRef.
     * First checks the cache for the package, if not in the cache then the method
     * will attempt to the locate the associated json file to load the package and
     * check there. If the API item can not be found the method will return undefined.
     */
    getItem(apiDefinitionRef: IApiDefinitionReference): IDocItem;
    /**
     * Attempts to locate and load the IDocPackage object from the project folder's
     * node modules. If the package already exists in the cache, nothing is done.
     *
     * @param apiDefinitionRef - interface with propropties pertaining to the API definition reference
     */
    getPackage(apiDefinitionRef: IApiDefinitionReference): IDocPackage;
}
