"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var ApiItem_1 = require("./ApiItem");
var ApiParameter_1 = require("./ApiParameter");
var TypeScriptHelpers_1 = require("../TypeScriptHelpers");
var PrettyPrinter_1 = require("../PrettyPrinter");
/**
  * This class is part of the ApiItem abstract syntax tree. It represents functions that are directly
  * defined inside a package and are not member of classes, interfaces, or nested type literal expressions
  *
  * @see ApiMethod for functions that are members of classes, interfaces, or nested type literal expressions
  */
var ApiFunction = (function (_super) {
    __extends(ApiFunction, _super);
    function ApiFunction(options) {
        var _this = _super.call(this, options) || this;
        var methodDeclaration = options.declaration;
        // Parameters
        if (methodDeclaration.parameters) {
            _this.params = [];
            for (var _i = 0, _a = methodDeclaration.parameters; _i < _a.length; _i++) {
                var param = _a[_i];
                var declarationSymbol = TypeScriptHelpers_1.default.tryGetSymbolForDeclaration(param);
                var docComment = declarationSymbol && _this.documentation && _this.documentation.paramDocs ?
                    _this.documentation.paramDocs.get(declarationSymbol.name) : '';
                _this.params.push(new ApiParameter_1.default({
                    analyzer: _this.analyzer,
                    declaration: param,
                    declarationSymbol: declarationSymbol
                }, docComment));
            }
        }
        _this.returnType = methodDeclaration.type ? methodDeclaration.type.getText() : '';
        return _this;
    }
    /**
     * Returns a text string such as "someName?: SomeTypeName;", or in the case of a type
     * literal expression, returns a text string such as "someName?:".
     */
    ApiFunction.prototype.getDeclarationLine = function () {
        return PrettyPrinter_1.default.getDeclarationSummary(this.declaration);
    };
    return ApiFunction;
}(ApiItem_1.default));
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = ApiFunction;

//# sourceMappingURL=ApiFunction.js.map
