import * as ts from 'typescript';
import { IApiItemOptions } from './ApiItem';
import ApiItemContainer from './ApiItemContainer';
/**
  * Indicates the type of definition represented by a ApiStructuredType object.
  */
export declare enum ApiStructuredTypeKind {
    /**
      * A TypeScript class.
      */
    Class = 0,
    /**
      * A TypeScript interface.
      */
    Interface = 1,
    /**
      * A TypeScript type literal expression, i.e. which defines an anonymous interface.
      */
    TypeLiteral = 2,
}
/**
  * This class is part of the ApiItem abstract syntax tree.  It represents a class,
  * interface, or type literal expression.
  */
export default class ApiStructuredType extends ApiItemContainer {
    kind: ApiStructuredTypeKind;
    implements?: string;
    extends?: string;
    /**
     * An array of type parameters for generic classes
     * Example: Foo<T, S> => ['T', 'S']
     */
    typeParameters: string[];
    /**
     * The data type of the ApiItem.declarationSymbol.  This is not the exported alias,
     * but rather the original that has complete member and inheritance information.
     */
    protected type: ts.Type;
    private _classLikeDeclaration;
    private _processedMemberNames;
    private _setterNames;
    constructor(options: IApiItemOptions);
    /**
      * Returns a line of text such as "class MyClass extends MyBaseClass", excluding the
      * curly braces and body.  The name "MyClass" will be the public name seend by external
      * callers, not the declared name of the class; @see ApiItem.name documentation for details.
      */
    getDeclarationLine(): string;
    private _processMember(memberSymbol, memberDeclaration);
}
