/// <reference types="mocha" />
"use strict";
var chai_1 = require("chai");
var ts = require("typescript");
var fsx = require("fs-extra");
var path = require("path");
var Analyzer_1 = require("../../Analyzer");
var ApiFileGenerator_1 = require("../../generators/ApiFileGenerator");
/* tslint:disable:no-function-expression - Mocha uses a poorly scoped "this" pointer */
function assertFileMatchesExpected(actualFilename, expectedFilename) {
    var actualContent = fsx.readFileSync(actualFilename).toString('utf8');
    var expectedContent = fsx.readFileSync(expectedFilename).toString('utf8');
    chai_1.assert(ApiFileGenerator_1.default.areEquivalentApiFileContents(actualContent, expectedContent), 'The file content does not match the expected value:'
        + '\nEXPECTED: ' + expectedFilename
        + '\nACTUAL: ' + actualFilename);
}
var capturedErrors = [];
function testErrorHandler(message, fileName, lineNumber) {
    capturedErrors.push({ message: message, fileName: fileName, lineNumber: lineNumber });
}
describe('ApiFileGenerator tests', function () {
    this.timeout(10000);
    describe('Basic Tests', function () {
        it('Example 1', function () {
            var analyzer = new Analyzer_1.default(testErrorHandler);
            var inputFolder = './testInputs/example1';
            var outputFile = './lib/example1-output.ts';
            var expectedFile = path.join(inputFolder, 'example1-output.ts');
            analyzer.analyze({
                compilerOptions: {
                    target: ts.ScriptTarget.ES5,
                    module: ts.ModuleKind.CommonJS,
                    moduleResolution: ts.ModuleResolutionKind.NodeJs,
                    rootDir: inputFolder
                },
                entryPointFile: path.join(inputFolder, 'index.ts')
            });
            var apiFileGenerator = new ApiFileGenerator_1.default();
            apiFileGenerator.writeApiFile(outputFile, analyzer);
            assertFileMatchesExpected(outputFile, expectedFile);
            /**
             * Errors can be found in testInputs/folder/MyClass
             */
            chai_1.assert.equal(capturedErrors.length, 2);
            chai_1.assert.equal(capturedErrors[0].message, 'Unknown JSDoc tag "@badjsdoctag"');
            chai_1.assert.equal(capturedErrors[1].message, 'Unexpected text in JSDoc comment: '
                + '"(Error #1 is the bad tag) Text can no..."');
        });
    });
});

//# sourceMappingURL=ApiFileGenerator.test.js.map
