/// <reference types="mocha" />
"use strict";
var ts = require("typescript");
var path = require("path");
var Analyzer_1 = require("../../Analyzer");
var ApiJsonGenerator_1 = require("../../generators/ApiJsonGenerator");
var TestFileComparer_1 = require("../../TestFileComparer");
/* tslint:disable:no-function-expression - Mocha uses a poorly scoped "this" pointer */
var capturedErrors = [];
function testErrorHandler(message, fileName, lineNumber) {
    capturedErrors.push({ message: message, fileName: fileName, lineNumber: lineNumber });
}
describe('ApiJsonGenerator tests', function () {
    this.timeout(10000);
    describe('Basic Tests', function () {
        it('Example 1', function () {
            var analyzer = new Analyzer_1.default(testErrorHandler);
            var inputFolder = './testInputs/example2';
            var outputFile = './lib/example2-output.json';
            var expectedFile = path.join(inputFolder, 'example2-output.json');
            analyzer.analyze({
                compilerOptions: {
                    target: ts.ScriptTarget.ES5,
                    module: ts.ModuleKind.CommonJS,
                    moduleResolution: ts.ModuleResolutionKind.NodeJs,
                    rootDir: inputFolder
                },
                entryPointFile: path.join(inputFolder, 'index.ts')
            });
            var apiJsonGenerator = new ApiJsonGenerator_1.default();
            apiJsonGenerator.writeJsonFile(outputFile, analyzer);
            TestFileComparer_1.default.assertFileMatchesExpected(outputFile, expectedFile);
        });
    });
});

//# sourceMappingURL=ApiJsonGenerator.test.js.map
